showPage property
If guard check returns false, beam to a BeamLocation with just that page.
This has precendence over beamTo and beamToNamed.
Implementation
final BeamPage? showPage;
If guard check returns false, beam to a BeamLocation with just that page.
This has precendence over beamTo and beamToNamed.
final BeamPage? showPage;